==> pulumi-azure-native-kotlin-2.19.0.0-sources.jar: com/pulumi/azurenative/servicefabric/kotlin/inputs/AveragePartitionLoadScalingTriggerArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.servicefabric.kotlin.inputs

import com.pulumi.azurenative.servicefabric.inputs.AveragePartitionLoadScalingTriggerArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.Double
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 * Represents a scaling trigger related to an average load of a metric/resource of a partition.
 * @property kind Enumerates the ways that a service can be partitioned.
 * Expected value is 'AveragePartitionLoadTrigger'.
 * @property lowerLoadThreshold The lower limit of the load below which a scale in operation should be performed.
 * @property metricName The name of the metric for which usage should be tracked.
 * @property scaleInterval The period in seconds on which a decision is made whether to scale or not. This property should come in ISO 8601 format "hh:mm:ss".
 * @property upperLoadThreshold The upper limit of the load beyond which a scale out operation should be performed.
 */
public data class AveragePartitionLoadScalingTriggerArgs(
    public val kind: Output<String>,
    public val lowerLoadThreshold: Output<Double>,
    public val metricName: Output<String>,
    public val scaleInterval: Output<String>,
    public val upperLoadThreshold: Output<Double>,
) :
    ConvertibleToJava<com.pulumi.azurenative.servicefabric.inputs.AveragePartitionLoadScalingTriggerArgs> {
    override fun toJava():
        com.pulumi.azurenative.servicefabric.inputs.AveragePartitionLoadScalingTriggerArgs =
        com.pulumi.azurenative.servicefabric.inputs.AveragePartitionLoadScalingTriggerArgs.builder()
            .kind(kind.applyValue({ args0 -> args0 }))
            .lowerLoadThreshold(lowerLoadThreshold.applyValue({ args0 -> args0 }))
            .metricName(metricName.applyValue({ args0 -> args0 }))
            .scaleInterval(scaleInterval.applyValue({ args0 -> args0 }))
            .upperLoadThreshold(upperLoadThreshold.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [AveragePartitionLoadScalingTriggerArgs].
 */
@PulumiTagMarker
public class AveragePartitionLoadScalingTriggerArgsBuilder internal constructor() {
    private var kind: Output<String>? = null

    private var lowerLoadThreshold: Output<Double>? = null

    private var metricName: Output<String>? = null

    private var scaleInterval: Output<String>? = null

    private var upperLoadThreshold: Output<Double>? = null

    /**
     * @param value Enumerates the ways that a service can be partitioned.
     * Expected value is 'AveragePartitionLoadTrigger'.
     */
    @JvmName("jqqxdklimygkkkvc")
    public suspend fun kind(`value`: Output<String>) {
        this.kind = value
    }

    /**
     * @param value The lower limit of the load below which a scale in operation should be performed.
     */
    @JvmName("gykvbqdaitqygndb")
    public suspend fun lowerLoadThreshold(`value`: Output<Double>) {
        this.lowerLoadThreshold = value
    }

    /**
     * @param value The name of the metric for which usage should be tracked.
     */
    @JvmName("ubokqaxmkagqgeva")
    public suspend fun metricName(`value`: Output<String>) {
        this.metricName = value
    }

    /**
     * @param value The period in seconds on which a decision is made whether to scale or not. This property should come in ISO 8601 format "hh:mm:ss".
     */
    @JvmName("xioekrvlivxcpjjl")
    public suspend fun scaleInterval(`value`: Output<String>) {
        this.scaleInterval = value
    }

    /**
     * @param value The upper limit of the load beyond which a scale out operation should be performed.
     */
    @JvmName("fehaabcmcnchddhm")
    public suspend fun upperLoadThreshold(`value`: Output<Double>) {
        this.upperLoadThreshold = value
    }

    /**
     * @param value Enumerates the ways that a service can be partitioned.
     * Expected value is 'AveragePartitionLoadTrigger'.
     */
    @JvmName("cvlasdcaegqqadcw")
    public suspend fun kind(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.kind = mapped
    }

    /**
     * @param value The lower limit of the load below which a scale in operation should be performed.
     */
    @JvmName("lfdnjrbydecklyrw")
    public suspend fun lowerLoadThreshold(`value`: Double) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.lowerLoadThreshold = mapped
    }

    /**
     * @param value The name of the metric for which usage should be tracked.
     */
    @JvmName("mqgydydyxepyoaui")
    public suspend fun metricName(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.metricName = mapped
    }

    /**
     * @param value The period in seconds on which a decision is made whether to scale or not. This property should come in ISO 8601 format "hh:mm:ss".
     */
    @JvmName("ihdbeehnalctirmi")
    public suspend fun scaleInterval(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.scaleInterval = mapped
    }

    /**
     * @param value The upper limit of the load beyond which a scale out operation should be performed.
     */
    @JvmName("tcxaqjufewrxmake")
    public suspend fun upperLoadThreshold(`value`: Double) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.upperLoadThreshold = mapped
    }

    internal fun build(): AveragePartitionLoadScalingTriggerArgs =
        AveragePartitionLoadScalingTriggerArgs(
            kind = kind ?: throw PulumiNullFieldException("kind"),
            lowerLoadThreshold = lowerLoadThreshold ?: throw PulumiNullFieldException("lowerLoadThreshold"),
            metricName = metricName ?: throw PulumiNullFieldException("metricName"),
            scaleInterval = scaleInterval ?: throw PulumiNullFieldException("scaleInterval"),
            upperLoadThreshold = upperLoadThreshold ?: throw PulumiNullFieldException("upperLoadThreshold"),
        )
}

==> pulumi-azure-native-kotlin-2.28.0.0-sources.jar: com/pulumi/azurenative/servicefabric/kotlin/inputs/AveragePartitionLoadScalingTriggerArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.servicefabric.kotlin.inputs

import com.pulumi.azurenative.servicefabric.inputs.AveragePartitionLoadScalingTriggerArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.Double
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 * Represents a scaling trigger related to an average load of a metric/resource of a partition.
 * @property kind Enumerates the ways that a service can be partitioned.
 * Expected value is 'AveragePartitionLoadTrigger'.
 * @property lowerLoadThreshold The lower limit of the load below which a scale in operation should be performed.
 * @property metricName The name of the metric for which usage should be tracked.
 * @property scaleInterval The period in seconds on which a decision is made whether to scale or not. This property should come in ISO 8601 format "hh:mm:ss".
 * @property upperLoadThreshold The upper limit of the load beyond which a scale out operation should be performed.
 */
public data class AveragePartitionLoadScalingTriggerArgs(
    public val kind: Output<String>,
    public val lowerLoadThreshold: Output<Double>,
    public val metricName: Output<String>,
    public val scaleInterval: Output<String>,
    public val upperLoadThreshold: Output<Double>,
) :
    ConvertibleToJava<com.pulumi.azurenative.servicefabric.inputs.AveragePartitionLoadScalingTriggerArgs> {
    override fun toJava():
        com.pulumi.azurenative.servicefabric.inputs.AveragePartitionLoadScalingTriggerArgs =
        com.pulumi.azurenative.servicefabric.inputs.AveragePartitionLoadScalingTriggerArgs.builder()
            .kind(kind.applyValue({ args0 -> args0 }))
            .lowerLoadThreshold(lowerLoadThreshold.applyValue({ args0 -> args0 }))
            .metricName(metricName.applyValue({ args0 -> args0 }))
            .scaleInterval(scaleInterval.applyValue({ args0 -> args0 }))
            .upperLoadThreshold(upperLoadThreshold.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [AveragePartitionLoadScalingTriggerArgs].
 */
@PulumiTagMarker
public class AveragePartitionLoadScalingTriggerArgsBuilder internal constructor() {
    private var kind: Output<String>? = null

    private var lowerLoadThreshold: Output<Double>? = null

    private var metricName: Output<String>? = null

    private var scaleInterval: Output<String>? = null

    private var upperLoadThreshold: Output<Double>? = null

    /**
     * @param value Enumerates the ways that a service can be partitioned.
     * Expected value is 'AveragePartitionLoadTrigger'.
     */
    @JvmName("srgwuxrchdjldxpf")
    public suspend fun kind(`value`: Output<String>) {
        this.kind = value
    }

    /**
     * @param value The lower limit of the load below which a scale in operation should be performed.
     */
    @JvmName("mjgmkeiptdqhemou")
    public suspend fun lowerLoadThreshold(`value`: Output<Double>) {
        this.lowerLoadThreshold = value
    }

    /**
     * @param value The name of the metric for which usage should be tracked.
     */
    @JvmName("fsiwekvorxrkvwvu")
    public suspend fun metricName(`value`: Output<String>) {
        this.metricName = value
    }

    /**
     * @param value The period in seconds on which a decision is made whether to scale or not. This property should come in ISO 8601 format "hh:mm:ss".
     */
    @JvmName("kposljeickvstdxe")
    public suspend fun scaleInterval(`value`: Output<String>) {
        this.scaleInterval = value
    }

    /**
     * @param value The upper limit of the load beyond which a scale out operation should be performed.
     */
    @JvmName("bidrrngrkalwnrmj")
    public suspend fun upperLoadThreshold(`value`: Output<Double>) {
        this.upperLoadThreshold = value
    }

    /**
     * @param value Enumerates the ways that a service can be partitioned.
     * Expected value is 'AveragePartitionLoadTrigger'.
     */
    @JvmName("nisorwnglvsxxhla")
    public suspend fun kind(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.kind = mapped
    }

    /**
     * @param value The lower limit of the load below which a scale in operation should be performed.
     */
    @JvmName("fcmomutrrtesyyee")
    public suspend fun lowerLoadThreshold(`value`: Double) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.lowerLoadThreshold = mapped
    }

    /**
     * @param value The name of the metric for which usage should be tracked.
     */
    @JvmName("gqvwpwpulbgwxseh")
    public suspend fun metricName(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.metricName = mapped
    }

    /**
     * @param value The period in seconds on which a decision is made whether to scale or not. This property should come in ISO 8601 format "hh:mm:ss".
     */
    @JvmName("plyujvovienprebw")
    public suspend fun scaleInterval(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.scaleInterval = mapped
    }

    /**
     * @param value The upper limit of the load beyond which a scale out operation should be performed.
     */
    @JvmName("mrqxgjbuwcjafhji")
    public suspend fun upperLoadThreshold(`value`: Double) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.upperLoadThreshold = mapped
    }

    internal fun build(): AveragePartitionLoadScalingTriggerArgs =
        AveragePartitionLoadScalingTriggerArgs(
            kind = kind ?: throw PulumiNullFieldException("kind"),
            lowerLoadThreshold = lowerLoadThreshold ?: throw PulumiNullFieldException("lowerLoadThreshold"),
            metricName = metricName ?: throw PulumiNullFieldException("metricName"),
            scaleInterval = scaleInterval ?: throw PulumiNullFieldException("scaleInterval"),
            upperLoadThreshold = upperLoadThreshold ?: throw PulumiNullFieldException("upperLoadThreshold"),
        )
}
